@@ -60,23 +60,23 @@ class StealthConfig:
         ```
     """
     # scripts
-    hairline: bool = False
+    hairline: bool = True
     dimensions: bool = True
     screen_touch: bool = True
     media_codecs: bool = True
-    iframe_content_window: bool = False
-    chrome_csi: bool = False
-    chrome_app: bool = False
-    chrome_runtime: bool = False
-    chrome_loadtimes: bool = False
+    iframe_content_window: bool = True
+    chrome_csi: bool = True
+    chrome_app: bool = True
+    chrome_runtime: bool = True
+    chrome_loadtimes: bool = True
     webdriver: bool = True
     webgl_vendor: bool = True
     navigator_vendor: bool = True
     navigator_plugins: bool = True
     navigator_platform: bool = True
-    navigator_languages: bool = False
+    navigator_languages: bool = True
     navigator_user_agent: bool = True
-    navigator_permissions: bool = False
+    navigator_permissions: bool = True
     navigator_hardware_concurrency: bool = True
 
     # options
